@@ -1,12 +1,15 @@
-from typing import Union
+from typing import List, Union
 
 from botocore.response import StreamingBody
 from mypy_boto3_s3 import S3Client
 from mypy_boto3_s3.type_defs import GetObjectOutputTypeDef, PutObjectOutputTypeDef
 from mypy_boto3_secretsmanager import SecretsManagerClient
 from mypy_boto3_secretsmanager.type_defs import GetSecretValueResponseTypeDef
+from mypy_boto3_ses import SESClient
+from mypy_boto3_ses.type_defs import SendEmailResponseTypeDef
 from mypy_boto3_sqs import SQSClient
 from mypy_boto3_sqs.type_defs import SendMessageResultTypeDef
+from pydantic import EmailStr
 
 from ..custom_types import HttpError
 from ..http_return import http_error
@@ -283,6 +286,92 @@ def send_sqs_message_fifo(
         )
 
 
+e = [
+    "AccountSendingPausedException",
+    "AlreadyExistsException",
+    "CannotDeleteException",
+    "ClientError",
+    "ConfigurationSetAlreadyExistsException",
+    "ConfigurationSetDoesNotExistException",
+    "ConfigurationSetSendingPausedException",
+    "CustomVerificationEmailInvalidContentException",
+    "CustomVerificationEmailTemplateAlreadyExistsException",
+    "CustomVerificationEmailTemplateDoesNotExistException",
+    "EventDestinationAlreadyExistsException",
+    "EventDestinationDoesNotExistException",
+    "FromEmailAddressNotVerifiedException",
+    "InvalidCloudWatchDestinationException",
+    "InvalidConfigurationSetException",
+    "InvalidDeliveryOptionsException",
+    "InvalidFirehoseDestinationException",
+    "InvalidLambdaFunctionException",
+    "InvalidPolicyException",
+    "InvalidRenderingParameterException",
+    "InvalidS3ConfigurationException",
+    "InvalidSNSDestinationException",
+    "InvalidSnsTopicException",
+    "InvalidTemplateException",
+    "InvalidTrackingOptionsException",
+    "LimitExceededException",
+    "MailFromDomainNotVerifiedException",
+    "MessageRejected",
+    "MissingRenderingAttributeException",
+    "ProductionAccessNotGrantedException",
+    "RuleDoesNotExistException",
+    "RuleSetDoesNotExistException",
+    "TemplateDoesNotExistException",
+    "TrackingOptionsAlreadyExistsException",
+    "TrackingOptionsDoesNotExistException",
+]
+
+
+def ses_send_email(
+    ses_client: SESClient,
+    ses_from_email: EmailStr,
+    ses_to_emails: List[EmailStr],
+    ses_email_subject: str,
+    ses_email_body: str,
+) -> Union[SendEmailResponseTypeDef, HttpError]:
+
+    try:
+        return ses_client.send_email(
+            Destination={"ToAddresses": ses_to_emails},
+            Message={
+                "Body": {
+                    "Html": {
+                        "Charset": "utf-8",
+                        "Data": ses_email_body,
+                    },
+                },
+                "Subject": {
+                    "Charset": "utf-8",
+                    "Data": ses_email_subject,
+                },
+            },
+            Source=ses_from_email,
+        )
+    except ses_client.exceptions.ClientError as ce:
+        status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
+        error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
+        return http_error(
+            status_code,
+            "SES Error",
+            [
+                f"Could not send SES email message from: {ses_from_email} to: {ses_to_emails}",
+                error_code,
+            ],
+        )
+    except Exception as ex:
+        return http_error(
+            status_int=500,
+            message="SES Error",
+            reasons=(
+                f"Could not send SES email message from: {ses_from_email} to: {ses_to_emails}"
+                f"becasue of {ex}"
+            ),
+        )
+
+
 # import boto3
 
 # sqs = boto3.client("sqs")
