@@ -30,11 +30,15 @@ def json_response(status_code: int, content: Any) -> JSONResponse:
 
 
 def json_error(status_code: int, message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(status_code, CustomError(message=message, reasons=reasons))
+    return json_response(
+        status_code=status_code, error=CustomError(message=message, reasons=reasons)
+    )
 
 
 def http_error(status_code: int, message: str, reasons: List[str]) -> HttpError:
-    return HttpError(status_code, CustomError(message, reasons))
+    return HttpError(
+        status_code=status_code, error=CustomError(message=message, reasons=reasons)
+    )
 
 
 def http_error_to_json_response(http_error: HttpError) -> JSONResponse:
@@ -48,8 +52,8 @@ def http_error_to_json_response(http_error: HttpError) -> JSONResponse:
 #
 
 
-def http_200_json(jsonable_content) -> JSONResponse:
-    return json_response(200, jsonable_content)
+def http_200_json(content) -> JSONResponse:
+    return json_response(status_code=200, content=content)
 
 
 #
@@ -58,15 +62,21 @@ def http_200_json(jsonable_content) -> JSONResponse:
 
 
 def http_400_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(400, CustomError(message=message, reasons=reasons))
+    return json_response(
+        status_code=400, content=CustomError(message=message, reasons=reasons)
+    )
 
 
 def http_403_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(403, CustomError(message=message, reasons=reasons))
+    return json_response(
+        status_code=403, content=CustomError(message=message, reasons=reasons)
+    )
 
 
 def http_404_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(404, CustomError(message=message, reasons=reasons))
+    return json_response(
+        status_code=404, content=CustomError(message=message, reasons=reasons)
+    )
 
 
 #
@@ -75,7 +85,9 @@ def http_404_json(message: str, reasons: List[str]) -> JSONResponse:
 
 
 def http_500_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(500, CustomError(message=message, reasons=reasons))
+    return json_response(
+        status_code=500, content=CustomError(message=message, reasons=reasons)
+    )
 
 
 def http_200_json_with_cookie(
@@ -87,7 +99,7 @@ def http_200_json_with_cookie(
     httponly: bool,
     domain: str,
 ) -> JSONResponse:
-    response = http_200_json(content)
+    response = http_200_json(content=content)
     response.set_cookie(
         key=key,
         value=value,
