@@ -1,5 +1,5 @@
 import base64
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Union
 
 import ecdsa
 from ecdsa import SigningKey, VerifyingKey
@@ -108,6 +108,43 @@ def get_jwt_field_from_cookies(
         )
 
 
+def get_jwt_fields_from_cookies(
+    cookies: Dict[str, Any],
+    name_of_jwt: str,
+    verifying_key: VerifyingKey,
+    audience: str,
+    jwt_field_names: List[str],
+) -> Union[List[str], List[CustomError]]:
+    try:
+
+        jwt_token_maybe = get_jwt_token_from_cookies(cookies, name_of_jwt)
+        if isinstance(jwt_token_maybe, CustomError):
+            return [jwt_token_maybe]
+
+        jwt_decoded_maybe = decode_jwt(jwt_token_maybe, verifying_key, audience)
+        if isinstance(jwt_decoded_maybe, CustomError):
+            return [jwt_decoded_maybe]
+
+        return list(
+            map(
+                lambda field_name: jwt_decoded_maybe.get(
+                    field_name,
+                    CustomError(
+                        message="JWT Error",
+                        reasons=[f"Could not get field: {field_name} from JWT token"],
+                    ),
+                ),
+                jwt_field_names,
+            ),
+        )
+
+    except Exception as ex:
+        return CustomError(
+            message="JWT Error",
+            reasons=[f"Could not get fields: {jwt_field_names} from JWT token {ex}"],
+        )
+
+
 def get_user_email_from_cookies(
     cookies: Dict[str, Any],
     name_of_jwt: str,
